@@ -1,24 +1,26 @@
-use std::cell::RefCell;
-use std::collections::HashSet;
-use std::env;
-use std::fs::{self, File, OpenOptions};
-use std::io::{Read, Write};
-use std::path::{Path, PathBuf};
-use std::rc::Rc;
+use std::{
+    cell::RefCell,
+    collections::HashSet,
+    env,
+    fs::{self, File, OpenOptions},
+    io::{Read, Write},
+    path::{Path, PathBuf},
+    rc::Rc,
+};
 
 use anyhow::{anyhow, Context};
-use cargo::core::{Dependency, PackageId, Summary, Verbosity, Workspace};
-use cargo::ops::{update_lockfile, UpdateOptions};
-use cargo::sources::config::SourceConfigMap;
-use cargo::util::{CargoResult, Config};
+use cargo::{
+    core::{Dependency, PackageId, QueryKind, Source, Summary, Verbosity, Workspace},
+    ops::{update_lockfile, UpdateOptions},
+    sources::config::SourceConfigMap,
+    util::{network::PollExt, CargoResult, Config},
+};
 use semver::{Version, VersionReq};
 use tempfile::{Builder, TempDir};
-use toml::value::Table;
-use toml::Value;
+use toml::{value::Table, Value};
 
 use super::{ElaborateWorkspace, Manifest};
-use crate::error::OutdatedError;
-use crate::Options;
+use crate::{error::OutdatedError, Options};
 
 /// A temporary project
 pub struct TempProject<'tmp> {
@@ -67,7 +69,7 @@ impl<'tmp> TempProject<'tmp> {
             tmp_manifest_paths.push(dest.clone());
             fs::copy(from, &dest)?;
 
-            //removing default-run key if it exists to check dependencies
+            // removing default-run key if it exists to check dependencies
             let mut om: Manifest = {
                 let mut buf = String::new();
                 let mut file = File::open(&dest)?;
@@ -83,11 +85,11 @@ impl<'tmp> TempProject<'tmp> {
                     .write(true)
                     .truncate(true)
                     .open(&dest)?;
-                write!(cargo_toml, "{}", om_serialized)?;
+                write!(cargo_toml, "{om_serialized}")?;
             }
 
-            // if build script is specified in the original Cargo.toml (from links or build) remove it as we do not need
-            // it for checking dependencies
+            // if build script is specified in the original Cargo.toml (from links or build)
+            // remove it as we do not need it for checking dependencies
             if om.package.contains_key("links") {
                 om.package.remove("links");
                 let om_serialized = ::toml::to_string(&om).expect("Cannot format as toml file");
@@ -96,7 +98,7 @@ impl<'tmp> TempProject<'tmp> {
                     .write(true)
                     .truncate(true)
                     .open(&dest)?;
-                write!(cargo_toml, "{}", om_serialized)?;
+                write!(cargo_toml, "{om_serialized}")?;
             }
 
             if om.package.contains_key("build") {
@@ -107,7 +109,7 @@ impl<'tmp> TempProject<'tmp> {
                     .write(true)
                     .truncate(true)
                     .open(&dest)?;
-                write!(cargo_toml, "{}", om_serialized)?;
+                write!(cargo_toml, "{om_serialized}")?;
             }
 
             let lockfile = from_dir.join("Cargo.lock");
@@ -135,7 +137,7 @@ impl<'tmp> TempProject<'tmp> {
         if workspace_root.join(".cargo/config.toml").is_file() {
             fs::create_dir_all(temp_dir.path().join(".cargo"))?;
             fs::copy(
-                &workspace_root.join(".cargo/config.toml"),
+                workspace_root.join(".cargo/config.toml"),
                 temp_dir.path().join(".cargo/config.toml"),
             )?;
         }
@@ -145,7 +147,7 @@ impl<'tmp> TempProject<'tmp> {
         if workspace_root.join(".cargo/config").is_file() {
             fs::create_dir_all(temp_dir.path().join(".cargo"))?;
             fs::copy(
-                &workspace_root.join(".cargo/config"),
+                workspace_root.join(".cargo/config"),
                 temp_dir.path().join(".cargo/config"),
             )?;
         }
@@ -224,7 +226,7 @@ impl<'tmp> TempProject<'tmp> {
     fn write_manifest<P: AsRef<Path>>(manifest: &Manifest, path: P) -> CargoResult<()> {
         let mut file = File::create(path)?;
         let serialized = ::toml::to_string(manifest).expect("Failed to serialized Cargo.toml");
-        write!(file, "{}", serialized)?;
+        write!(file, "{serialized}")?;
         Ok(())
     }
 
@@ -256,6 +258,13 @@ impl<'tmp> TempProject<'tmp> {
                 }
             }
         }
+        if let Some(t) = manifest.patch.as_mut() {
+            for (_key, patch) in t.iter_mut() {
+                if let Value::Table(ref mut patch) = *patch {
+                    f(patch)?;
+                }
+            }
+        }
         Ok(())
     }
 
@@ -382,11 +391,14 @@ impl<'tmp> TempProject<'tmp> {
             let _lock = ws_config.acquire_package_cache_lock()?;
             let source_config = SourceConfigMap::new(ws_config)?;
             let mut source = source_config.load(source_id, &HashSet::new())?;
-            if !source_id.is_default_registry() {
-                source.update()?;
+            if !source_id.is_crates_io() {
+                source.invalidate_cache();
             }
+            source.block_until_ready()?;
             let dependency = Dependency::parse(name, None, source_id)?;
-            let mut query_result = source.query_vec(&dependency)?;
+            let mut query_result = source
+                .query_vec(&dependency, QueryKind::Exact)?
+                .expect("Source should be ready");
             query_result.sort_by(|a, b| b.version().cmp(a.version()));
             query_result
         };
@@ -415,10 +427,11 @@ impl<'tmp> TempProject<'tmp> {
             None => {
                 // If the version_req cannot be found use the version
                 // this happens when we use a git repository as a dependency, without specifying
-                // the version in Cargo.toml, preventing us from needing an unwrap below in the warn
+                // the version in Cargo.toml, preventing us from needing an unwrap below in the
+                // warn
                 let ver_req = match version_req {
-                    Some(v_r) => format!("{}", v_r),
-                    None => format!("{}", version),
+                    Some(v_r) => format!("{v_r}"),
+                    None => format!("{version}"),
                 };
                 // this should be safe it should only fail if we cannot get
                 // access to write to the terminal
@@ -430,7 +443,7 @@ impl<'tmp> TempProject<'tmp> {
                     query_result[0].version()
                 ))?;
 
-                //this returns the latest version
+                // this returns the latest version
                 &query_result[0]
             }
         };
@@ -467,9 +480,9 @@ impl<'tmp> TempProject<'tmp> {
             visited.insert(feature);
             if features_table.contains_key(feature) {
                 let specified_features = match features_table.get(feature) {
-                    None => panic!("Feature {} does not exist", feature),
-                    Some(&Value::Array(ref specified_features)) => specified_features,
-                    _ => panic!("Feature {} is not mapped to an array", feature),
+                    None => panic!("Feature {feature} does not exist"),
+                    Some(Value::Array(ref specified_features)) => specified_features,
+                    _ => panic!("Feature {feature} is not mapped to an array"),
                 };
                 for spec in specified_features {
                     if let Value::String(ref spec) = *spec {
@@ -493,8 +506,8 @@ impl<'tmp> TempProject<'tmp> {
         for dep_key in dep_keys {
             // this, by brute force, allows a user to exclude a dependency by not writing
             // it to the temp project's manifest
-            // In short this allows cargo to build the package with semver minor compatibilities issues
-            // https://github.com/rust-lang/cargo/issues/6584
+            // In short this allows cargo to build the package with semver minor
+            // compatibilities issues https://github.com/rust-lang/cargo/issues/6584
             // https://github.com/kbknapp/cargo-outdated/issues/230
             if self.options.exclude.contains(&dep_key) {
                 continue;
@@ -530,8 +543,8 @@ impl<'tmp> TempProject<'tmp> {
                 }
                 Value::Table(ref t) => {
                     let mut name = match t.get("package") {
-                        Some(&Value::String(ref s)) => s,
-                        Some(_) => panic!("'package' of dependency {} is not a string", dep_key),
+                        Some(Value::String(ref s)) => s,
+                        Some(_) => panic!("'package' of dependency {dep_key} is not a string"),
                         None => &dep_key,
                     };
 
@@ -559,8 +572,8 @@ impl<'tmp> TempProject<'tmp> {
                     }
                     let mut replaced = t.clone();
                     let requirement = match t.get("version") {
-                        Some(&Value::String(ref requirement)) => Some(requirement.as_str()),
-                        Some(_) => panic!("Version of {} is not a string", name),
+                        Some(Value::String(ref requirement)) => Some(requirement.as_str()),
+                        Some(_) => panic!("Version of {name} is not a string"),
                         _ => None,
                     };
                     let r_summary = self.find_update(
@@ -589,20 +602,20 @@ impl<'tmp> TempProject<'tmp> {
                     }
                     if replaced.contains_key("features") {
                         let features = match replaced.get("features") {
-                            Some(&Value::Array(ref features)) => features
+                            Some(Value::Array(ref features)) => features
                                 .iter()
                                 .filter(|&feature| {
                                     let feature = match *feature {
                                         Value::String(ref feature) => feature,
                                         _ => panic!(
-                                            "Features section of {} is not an array of strings",
-                                            name
+                                            "Features section of {name} is not an array of strings"
                                         ),
                                     };
                                     let retained =
                                         features_and_options(&summary).contains(feature.as_str());
-                                    // this unwrap should be safe it should only fail if we cannot get
-                                    // access to write to the terminal
+                                    // this unwrap should be safe it should only fail if we cannot
+                                    // get access to write to
+                                    // the terminal
                                     // if this fails it's a cargo (as a dependency) issue
                                     if !retained {
                                         self.warn(format!(
@@ -618,16 +631,13 @@ impl<'tmp> TempProject<'tmp> {
                                 })
                                 .cloned()
                                 .collect::<Vec<Value>>(),
-                            _ => panic!("Features section of {} is not an array", name),
+                            _ => panic!("Features section of {name} is not an array"),
                         };
                         replaced.insert("features".to_owned(), Value::Array(features));
                     }
                     dependencies.insert(name.clone(), Value::Table(replaced));
                 }
-                _ => panic!(
-                    "Dependency spec is neither a string nor a table {}",
-                    dep_key
-                ),
+                _ => panic!("Dependency spec is neither a string nor a table {dep_key}"),
             }
         }
         Ok(())
@@ -751,8 +761,9 @@ fn manifest_paths(elab: &ElaborateWorkspace<'_>) -> CargoResult<Vec<PathBuf>> {
             _ => None,
         };
 
-        // If there is a CARGO_HOME make sure we do not crawl the registry for more Cargo.toml files
-        // Otherwise add all Cargo.toml files to the manifest paths
+        // If there is a CARGO_HOME make sure we do not crawl the registry for more
+        // Cargo.toml files Otherwise add all Cargo.toml files to the manifest
+        // paths
         if pkg.root().starts_with(PathBuf::from(workspace_path))
             && (cargo_home_path.is_none()
                 || !pkg_path
@@ -770,7 +781,8 @@ fn manifest_paths(elab: &ElaborateWorkspace<'_>) -> CargoResult<Vec<PathBuf>> {
 
     // executed against a virtual manifest
     let workspace_path = elab.workspace.root().to_string_lossy();
-    // if cargo workspace is not explicitly used, the package itself would be a member
+    // if cargo workspace is not explicitly used, the package itself would be a
+    // member
     for member in elab.workspace.members() {
         let root_pkg_id = member.package_id();
         manifest_paths_recursive(
