@@ -11,11 +11,11 @@ mod error;
 
 use std::collections::HashSet;
 
-use cargo::core::shell::Verbosity;
-use cargo::core::Workspace;
-use cargo::ops::needs_custom_http_transport;
-use cargo::util::important_paths::find_root_manifest_for_wd;
-use cargo::util::{CargoResult, CliError, Config};
+use cargo::{
+    core::{shell::Verbosity, Workspace},
+    ops::needs_custom_http_transport,
+    util::{important_paths::find_root_manifest_for_wd, CargoResult, CliError, Config},
+};
 
 use crate::{
     cargo_ops::{ElaborateWorkspace, TempProject},
@@ -55,7 +55,7 @@ fn main() {
         Err(e) => {
             config.shell().set_verbosity(Verbosity::Normal);
             let cli_error = CliError::new(e, 1);
-            cargo::exit_with_error(cli_error, &mut *config.shell())
+            cargo::exit_with_error(cli_error, &mut config.shell())
         }
         Ok(i) => {
             if i > 0 {
@@ -90,7 +90,7 @@ pub fn execute(options: Options, config: &mut Config) -> CargoResult<i32> {
         &[],
         &[],
     )?;
-    debug!(config, format!("options: {:?}", options));
+    debug!(config, format!("options: {options:?}"));
 
     verbose!(config, "Parsing...", "current workspace");
     // the Cargo.toml that we are actually working on
